<?php


/**
 * add_to_cart hook - html shown on product page for adding product to shoppingcart
 */
add_action('woocommerce_calculate_add_to_cart', function() {
	global $product;
	
	$product_id = esc_attr($product->id);
	$button_text = $product->single_add_to_cart_text();
	
	$w_price = json_encode(get_post_meta($product->id, 'calculate_type_width', true));
	$h_price = json_encode(get_post_meta($product->id, 'calculate_type_height', true));
	
	
	// TODO: use wc_get_template() for templates
	print '<form class="cart" method="post" enctype="multipart/form-data">';
	do_action( 'woocommerce_before_add_to_cart_form' );
	print <<<HTML
	
		<input type="hidden" name="add-to-cart" value="{$product_id}" />
		
		<input type="text" name="product_width" placeholder="Width" /> x <input type="text" name="product_height" placeholder="height" />
		
		<button type="submit" class="single_add_to_cart_button button alt">{$button_text}</button>
		
		<script>
			jQuery('input[name=product_width], input[name=product_height]').bind('keyup change', function() {
				var w = parseInt( jQuery('input[name=product_width]').val() );
				var h = parseInt( jQuery('input[name=product_height]').val() );
				
				if (isNaN(w))
					w = 1;
				if (isNaN(h))
					h = 1;
				
				var p = ($w_price * w) + ($h_price * h);
				
				jQuery('p.price').text('Price: ' + p);
			});
		</script>
		
HTML;

	do_action( 'woocommerce_after_add_to_cart_form' );
	print '</form>';
	
});



/**
 * add_to_cart handler, creates a new product and adds it to the shoppingcart
 */
add_action('woocommerce_add_to_cart_handler_calculate', function($url) {
	$product_id = (int)$_REQUEST['add-to-cart'];
	$product_width = (float)$_REQUEST['product_width'];
	$product_height = (float)$_REQUEST['product_height'];
	

	$post = get_post($product_id);
	
	$variant_id = add_calculate_type_variation($product_id, $product_width, $product_height);
	$r = WC()->cart->add_to_cart( $variant_id, 1 );
	
	if ( $r !== false ) {
		wc_add_to_cart_message( array( $product_id => 1 ), true );
		return true;
	}
	
}, 100, 1);


/**
 * code that adds the product for the shoppingcart
 */
function add_calculate_type_variation($product_id, $width, $height) {
	$parent_post = get_post($product_id);
	
	$w_price = get_post_meta($parent_post->ID, 'calculate_type_width', true);
	$h_price = get_post_meta($parent_post->ID, 'calculate_type_height', true);
	
	if (is_numeric($width) == false || $width < 1)
		$width = 1;
	if (is_numeric($height) == false || $height < 1)
		$height = 1;
	
	$price = ($width * $w_price) + ($height * $h_price);
	
	
	// code copied from from plugins/woocommerce/inclues/class-wc-ajax.php
	$variation = array(
			'post_title'   => "{$width}x{$height}",			// in the shoppingbag description, the title of the parent will also be shown
			'post_content' => '',
			'post_status'  => 'publish',
			'post_parent'  => $parent_post->ID,
			'post_type'    => 'product_calc_var',
			'menu_order'   => -1
	);
	
	$variation_id = wp_insert_post( $variation );
	
	
	if ( $variation_id ) {
		update_post_meta($variation_id, '_price', $price);
		update_post_meta($variation_id, '_width', $width);
		update_post_meta($variation_id, '_height', $height);
		
		return $variation_id;
	}
	
	return null;
}


